/**
 * @packageDocumentation
 * @module Array
 */
import { ObservableInput, OperatorFunction } from 'rxjs';
/**
 * Returns an Observable Array containing unique values that are not in the provided input Array or Set
 *
 * @category Filter
 *
 * @see [[filterDifference]] operator for an Array containing potential duplicate differences
 *
 * @typeParam T Item type contained in the Array/Set
 *
 * @param input Array/Set or Observable value to compare against for the difference
 *
 * @example
 * Returns the difference between the source array and the passed static array
 * ```ts
 * const input = ['a', 'b', 'd', 'a', 'b'];
 * of(input).pipe(difference(['a', 'c'])).subscribe();
 * ```
 * Output: `['b', 'd']`
 *
 * @example
 * Returns the difference between the source array and the passed Observable array
 * ```ts
 * const input = ['a', 'b', 'd', 'a', 'b'];
 * of(input).pipe(difference(of(['a', 'c']))).subscribe();
 * ```
 * Output: `['b', 'd']`
 *
 * @returns An Observable that emits an Array containing a subset of the source value
 */
export declare function difference<T extends unknown>(input: T[] | Set<T> | ObservableInput<T[] | Set<T>>): OperatorFunction<T[] | Set<T>, T[]>;
